#!/bin/bash
python src/__init__.py
# python test.py
